==> apo_0.1.5.tar.gz: apoinstall/rss.php <==
<?php
	if(isset($_GET["username"])){
		$getUserName = $_GET["username"];
		
		$apoDir = dirname(__FILE__);
		$apoFile = basename(__FILE__);
		require $apoDir."/config/config.php";
		
		// Instanciation de Apo
		$apo = new Apo($apoDir, $apoFile, $connApo);
		
		// Configuration
		$apo->config = $apoDir."/config/config.ini";
		
		// Recherche du userId
		$apo->db->select($apo->dbPrefix."users", "id", "name='".$getUserName."'");
		$getId = $apo->db->fetch_single();
		if($getId){
			require_once $apoDir."/modules/rss/functions.php";
			
			// Récupération de tous les fils de l'utilisateur
			$apo->db->select($apo->dbPrefix."rss", "*", "userId=".$getId);
			$listRss = array();
			while($row = $apo->db->fetch_array()){
				$o = $row;
				$o["name"] = htmlentities($o["name"]);
				$listRss[] = $o;
			}
			// Inclusion de magpie
			require_once  $apoDir."/modules/rss/magpie/rss_fetch.inc";
			
			// Définition du répertoire de cache
			define('MAGPIE_CACHE_DIR', $apoDir."/modules/rss/cache");
			
			for($i=0; $i<count($listRss);$i++){
				$magpie_fetch_result = @fetch_rss($listRss[$i]["url"]);
				if($magpie_fetch_result){
					$listRss[$i]["magpie"] = $magpie_fetch_result;
					//$listRss[$i]["lastArchive"] = date("Y-m-d H:i:s");
					// Dernière date d'enregistrement des archives
					$apo->db->select($apo->dbPrefix."rss_archives", "date", "url='".$listRss[$i]["url"]."'", null, null, array("date"=>"DESC"), array(0, 1));
					if($lastArchive = $apo->db->fetch_single()){
						$listRss[$i]["lastArchive"] = $lastArchive;
					}else{
						$listRss[$i]["lastArchive"] = "0000-00-00 00:00:00";
					}
				}else{
					$apo->error = $apo->getText("rss_error_feed")." : ".$listRss[$i]["url"];
				}
			}
			
			$o = rss_getList($listRss); 
			if($o["total"] > 0){
				$content = $o["content"];
			}else{
				if(count($listRss) > 0){
					$content = "<p>".$apo->getText("rss_nonews")."</p>";
				}else{
					$content = "<p></p>";
				}
			}
		}else{
			$content = "<p>Mauvais identifiant.</p>";
		}
	}else{
		$content = "<p>ERREUR</p>";
	}
	
	// Envoi des en-tête HTTP
	$accept_xml = !empty($_SERVER['HTTP_ACCEPT']) && strpos($_SERVER['HTTP_ACCEPT'],'application/xhtml+xml') !== false;
	if ($accept_xml) {
		header('Content-Type: application/xhtml+xml');
	} else {
		header('Content-Type: text/html; charset=UTF-8');
	}
	
	// Affichage du HTML
	if ($accept_xml) {
		echo '<?xml version="1.0" encoding="UTF-8"?>'."\n";
	}
?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="<?php echo $apo->lang; ?>" lang="<?php echo $apo->lang; ?>">
	<head>
		<meta http-equiv="Content-Type" content="text/html; charset=UTF-8" />
		<meta http-equiv="Content-Style-Type" content="text/css" />
		<link rel="stylesheet" type="text/css" href="<?php echo $apo->webRoot; ?>/themes/<?php echo $apo->theme; ?>/style.css" />
		<title><?php echo $apo->getText("menu_rss"); ?></title>
		<script type="text/javascript" src="<?php echo $apo->webRoot; ?>/js/functions.js"></script>
	</head>
	<body>
		<?php echo $apo->error; ?>
		<div id="content" class="rsspublic">
			<h1><?php echo $apo->getText("menu_rss"); ?> &gt; <?php echo $getUserName; ?></h1>
			<?php echo $content; ?>
		</div>
	</body>
</html>

==> apo_0.2.4.tar.gz: apoinstall/rss.php <==
<?php
	if(isset($_GET["username"])){
		$getUserName = $_GET["username"];
		
		$apoDir = dirname(__FILE__);
		$apoFile = basename(__FILE__);
		require $apoDir."/config/config.php";
		
		// Instanciation de Apo
		$apo = new Apo($apoDir, $apoFile, $connApo);
		
		// Configuration
		$apo->config = $apoDir."/config/config.ini";
		
		// Recherche du userId
		$apo->db->select($apo->dbPrefix."users", "id", "name='".$getUserName."'");
		$getId = $apo->db->fetch_single();
		if($getId){
			require_once $apoDir."/modules/rss/functions.inc";
			
			// Récupération de tous les fils de l'utilisateur
			$apo->db->select($apo->dbPrefix."rss", "*", "userId=".$getId);
			$listRss = array();
			while($row = $apo->db->fetch_array()){
				$o = $row;
				$o["name"] = htmlentities($o["name"]);
				$listRss[] = $o;
			}
			// Inclusion de magpie
			require_once  $apoDir."/modules/rss/magpie/rss_fetch.inc";
			
			// Définition du répertoire de cache
			define('MAGPIE_CACHE_DIR', $apoDir."/modules/rss/cache");
			
			for($i=0; $i<count($listRss);$i++){
				$magpie_fetch_result = @fetch_rss($listRss[$i]["url"]);
				if($magpie_fetch_result){
					$listRss[$i]["magpie"] = $magpie_fetch_result;
					//$listRss[$i]["lastArchive"] = date("Y-m-d H:i:s");
					// Dernière date d'enregistrement des archives
					$apo->db->select($apo->dbPrefix."rss_archives", "date", "url='".$listRss[$i]["url"]."'", null, null, array("date"=>"DESC"), array(0, 1));
					if($lastArchive = $apo->db->fetch_single()){
						$listRss[$i]["lastArchive"] = $lastArchive;
					}else{
						$listRss[$i]["lastArchive"] = "0000-00-00 00:00:00";
					}
				}else{
					$apo->error = $apo->getText("rss_error_feed")." : ".$listRss[$i]["url"];
				}
			}
			
			$o = rss_getList($listRss); 
			if($o["total"] > 0){
				$content = $o["content"];
			}else{
				if(count($listRss) > 0){
					$content = "<p>".$apo->getText("rss_nonews")."</p>";
				}else{
					$content = "<p></p>";
				}
			}
		}else{
			$content = "<p>Mauvais identifiant.</p>";
		}
	}else{
		$content = "<p>ERREUR</p>";
	}
	
	// Envoi des en-tête HTTP
	$accept_xml = !empty($_SERVER['HTTP_ACCEPT']) && strpos($_SERVER['HTTP_ACCEPT'],'application/xhtml+xml') !== false;
	if ($accept_xml) {
		header('Content-Type: application/xhtml+xml');
	} else {
		header('Content-Type: text/html; charset=UTF-8');
	}
	
	// Affichage du HTML
	if ($accept_xml) {
		echo '<?xml version="1.0" encoding="UTF-8"?>'."\n";
	}
?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="<?php echo $apo->lang; ?>" lang="<?php echo $apo->lang; ?>">
	<head>
		<meta http-equiv="Content-Type" content="text/html; charset=UTF-8" />
		<meta http-equiv="Content-Style-Type" content="text/css" />
		<link rel="stylesheet" type="text/css" href="<?php echo $apo->webRoot; ?>/themes/<?php echo $apo->theme; ?>/style.css" />
		<title><?php echo $apo->getText("menu_rss"); ?></title>
		<script type="text/javascript" src="<?php echo $apo->webRoot; ?>/js/functions.js"></script>
	</head>
	<body>
		<?php echo $apo->error; ?>
		<div id="content" class="rsspublic">
			<h1><?php echo $apo->getText("menu_rss"); ?> &gt; <?php echo $getUserName; ?></h1>
			<?php echo $content; ?>
		</div>
	</body>
</html>
